#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 witherable
version:              0.4.2
visibility:           public
id:                   witherable-0.4.2-1jE431H30IYHv7bfg75yv9
key:                  witherable-0.4.2-1jE431H30IYHv7bfg75yv9
license:              BSD-3-Clause
copyright:            Copyright (c) 2014 Fumiaki Kinoshita
maintainer:           Fumiaki Kinoshita <fumiexcel@gmail.com>
author:               Fumiaki Kinoshita
homepage:             https://github.com/fumieval/witherable
synopsis:             filterable traversable
description:
    A stronger variant of `traverse` which can remove elements and generalised mapMaybe, catMaybes, filter

category:             Data
abi:                  0670a345d816eb8e48398cb2f51f11a3
exposed:              True
exposed-modules:      Data.Witherable Witherable
import-dirs:          /usr/lib/ghc-9.6.6/site-local/witherable-0.4.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/witherable-0.4.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/witherable-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-witherable
hs-libraries:         HSwitherable-0.4.2-1jE431H30IYHv7bfg75yv9
depends:
    base-4.18.2.1 base-orphans-0.9.3-GOhTs05VlmS5lziBPhvbDU
    containers-0.6.7 hashable-1.4.7.0-IVKAR4D6WU9H8t6zzGQ76p
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    indexed-traversable-instances-0.1.2.1-JhOlpoHKiTLijrqFu1zjb
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-FX7g4DMKoiaDV91wUmRzTu
    vector-0.13.2.0-E81GJWrGuCo4SgJOIsfBQo

haddock-interfaces:   /usr/share/doc/haskell-witherable/html/witherable.haddock
haddock-html:         /usr/share/doc/haskell-witherable/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

